@@ -558,6 +558,30 @@ impl EnvVars {
     #[attr_added_in("0.3.4")]
     pub const UV_INTERNAL__TEST_DIR: &'static str = "UV_INTERNAL__TEST_DIR";
 
+    /// Path to a directory on a filesystem that supports copy-on-write, e.g., btrfs or APFS.
+    ///
+    /// When populated, uv will run additional tests that require this functionality.
+    #[attr_hidden]
+    #[attr_added_in("0.10.5")]
+    pub const UV_INTERNAL__TEST_COW_FS: &'static str = "UV_INTERNAL__TEST_COW_FS";
+
+    /// Path to a directory on a filesystem that does **not** support copy-on-write.
+    ///
+    /// When populated, uv will run additional tests that verify fallback behavior
+    /// when copy-on-write is unavailable.
+    #[attr_hidden]
+    #[attr_added_in("0.10.5")]
+    pub const UV_INTERNAL__TEST_NOCOW_FS: &'static str = "UV_INTERNAL__TEST_NOCOW_FS";
+
+    /// Path to a directory on an alternative filesystem for testing.
+    ///
+    /// This filesystem must be a different device than the default for the test suite.
+    ///
+    /// When populated, uv will run additional tests that cover cross-filesystem linking.
+    #[attr_hidden]
+    #[attr_added_in("0.10.5")]
+    pub const UV_INTERNAL__TEST_ALT_FS: &'static str = "UV_INTERNAL__TEST_ALT_FS";
+
     /// Used to force treating an interpreter as "managed" during tests.
     #[attr_hidden]
     #[attr_added_in("0.8.0")]
